pub struct CsvDataset<'a> {
pub names: Vec<ColName>,
pub values: Vec<Vec<CsvAny>>,
pub null_values: NullValues<'a>,
pub info: Vec<ColumnInfo>,
}Expand description
This is a form to represent the dataset which does not deep typization but can still be usefull, also info field holds some info about the types for each column
Fields
names: Vec<ColName>values: Vec<Vec<CsvAny>>null_values: NullValues<'a>info: Vec<ColumnInfo>Implementations
Sourceimpl<'a> CsvDataset<'a>
impl<'a> CsvDataset<'a>
Sourcepub fn push(&mut self, col_name: &str, col_values: Vec<CsvAny>)
pub fn push(&mut self, col_name: &str, col_values: Vec<CsvAny>)
Lenght of column values are not checked, so every column can have different lenght, be aware of row indexing
pub fn new<R: Read>(reader: Reader<R>, null_values: NullValues<'a>) -> Self
pub fn view_names_and_values(&self) -> ValueNamesView<'_>
pub fn split_view_and_info( &mut self, ) -> (ValueNamesView<'_>, &mut Vec<ColumnInfo>)
Sourcepub fn populate_column_infos(dataset: &mut Self)
pub fn populate_column_infos(dataset: &mut Self)
Analyze every cell in the csv file to extract every unique value